# Stream
Stream is a HW architecture-mapping design space exploration (DSE) framework for multi-core deep learning accelerators. The mapping can be explored at different granularities, ranging from classical layer-by-layer processing to fine-grained layer-fused processing. Stream builds on top of the ZigZag DSE framework, found [here](https://zigzag-project.github.io/zigzag/). 

More information with respect to the capabilities of Stream can be found in the following paper:

[A. Symons, L. Mei, S. Colleman, P. Houshmand, S. Karl and M. Verhelst, “Towards Heterogeneous Multi-core Accelerators Exploiting Fine-grained Scheduling of Layer-Fused Deep Neural Networks”, <i>arXiv e-prints</i>, 2022. doi:10.48550/arXiv.2212.10612.](https://arxiv.org/abs/2212.10612)

## Documentation

Documentation for Stream is underway!
